eggbasket.odict.Items

Package eggbasket :: Module odict :: Class Items |
[show private | hide private]
[frames | no frames]

## Type Items

    object --+
             |
            Items

Custom object for accessing the items of an OrderedDict.

Can be called like the normal `OrderedDict.items` method, but also supports indexing and sequence methods.

Method Summary
| `__init__(self, main)`
| `__add__(self, other)`
| ``__call__`(self)` Pretend to be the items method.
| `__cmp__(self, other)`
| `__contains__(self, item)`
| ``__delitem__`(self, i)` Delete the item at position i.
| `__eq__(self, other)`
| `__ge__(self, other)`
| ``__getitem__`(self, index)` Fetch the item at position i.
| `__gt__(self, other)`
| `__iadd__(self, other)`
| `__imul__(self, n)`
| `__iter__(self)`
| `__le__(self, other)`
| `__len__(self)`
| `__lt__(self, other)`
| `__mul__(self, n)`
| `__ne__(self, other)`
| `__radd__(self, other)`
| `__repr__(self)`
| `__rmul__(self, n)`
| ``__setitem__`(self, index, item)` Set item at position i to item.
| ``append`(self, item)` Add an item to the end.
| `count(self, item)`
| `extend(self, other)`
| `index(self, item, *args)`
| `insert(self, i, item)`
| `pop(self, i)`
| `remove(self, item)`
| `reverse(self)`
| `sort(self, *args, **kwds)`
Inherited from object
| ``__delattr__`(...)` x.__delattr__('name') <==> del x.name
| ``__getattribute__`(...)` x.__getattribute__('name') <==> x.name
| ``__hash__`(x)` x.__hash__() <==> hash(x)
| ``__new__`(T, S, ...)` T.__new__(S, ...) -> a new object with type S, a subtype of T
| ``__reduce__`(...)` helper for pickle
| ``__reduce_ex__`(...)` helper for pickle
| ``__setattr__`(...)` x.__setattr__('name', value) <==> x.name = value
| ``__str__`(x)` x.__str__() <==> str(x)

Method Details

### __call__(self) (Call operator) Pretend to be the items method.

### __delitem__(self, i) (Index deletion operator) Delete the item at position i.

### __getitem__(self, index) (Indexing operator) Fetch the item at position i.

### __setitem__(self, index, item) (Index assignment operator) Set item at position i to item.

### append(self, item) Add an item to the end.

Generated by Epydoc 2.1 on Mon Apr 21 14:16:56 2008 | http://epydoc.sf.net